.. _xrtpy-response: *************************** Response (`xrtpy.response`) *************************** .. py:module:: xrtpy.response .. currentmodule:: xrtpy.response Introduction ============ The `xrtpy.response` subpackage includes functionality for describing XRT_ channels & filters, finding the effective area, and calculating the temperature response function. Submodules ========== .. toctree:: :maxdepth: 2 channel API === .. automodapi:: xrtpy.response :noindex: :no-main-docstring: